@@ -50,9 +50,12 @@ struct __scrotoptions
    int pointer;
    int freeze;
    int overwrite;
+   int line_style;
+   int line_width;
    char *output_file;
    char *thumb_file;
    char *exec;
+   char *note;
    int autoselect;
    int autoselect_x;
    int autoselect_y;
@@ -64,6 +67,8 @@ void init_parse_options(int argc, char **argv);
 char *name_thumbnail(char *name);
 void options_parse_thumbnail(char *optarg);
 void options_parse_autoselect(char *optarg);
+void options_parse_note(char *optarg);
+int  options_parse_required_number(char *str);
 extern scrotoptions opt;
 
 #endif
